@@ -4,10 +4,9 @@ import atc
 
 
 class TestSparkImport(unittest.TestCase):
-
     def test_spark(self):
-        Spark = atc.Spark
+        Spark = atc.spark
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
